@@ -11,11 +11,7 @@ const (
 )
 
 var (
-	clusterRoleBindingGVK = schema.GroupVersionKind{
-		Group:   rbacV1.GroupName,
-		Version: "v1",
-		Kind:    ClusterRoleBinding,
-	}
+	clusterRoleBindingGVK = rbacV1.SchemeGroupVersion.WithKind("ClusterRoleBinding")
 )
 
 func init() {
@@ -23,3 +19,8 @@ func init() {
 		return gvk == clusterRoleBindingGVK
 	}))
 }
+
+// GetClusterRoleBindingAPIVersion returns ClusterRoleBinding's APIVersion
+func GetClusterRoleBindingAPIVersion() string {
+	return clusterRoleBindingGVK.GroupVersion().String()
+}
